precision highp float;

varying vec2 v_texCoord;
uniform sampler2D u_texSampler;
uniform float u_imageWidth;
uniform float u_imageHeight;
uniform float u_floatParam;

float rand(vec2 loc) {
    float theta1 = dot(loc, vec2(0.9898, 0.233));
    float theta2 = dot(loc, vec2(12.0, 78.0));
    float value = cos(theta1) * sin(theta2) + sin(theta1) * cos(theta2);
    // keep value of part1 in range: (2^-14 to 2^14).
    float temp = mod(197.0 * value, 1.0) + value;
    float part1 = mod(220.0 * temp, 1.0) + temp;
    float part2 = value * 0.5453;
    float part3 = cos(theta1 + theta2) * 0.43758;
    return fract(part1 + part2 + part3);
}

float lumen() {
   float shade = 0.85;
   float slope = 20.0;
   vec2 scale;
   if (u_imageWidth > u_imageHeight) {
       scale.x = 1.0;
       scale.y = u_imageHeight / u_imageWidth;
   } else {
       scale.x = u_imageWidth / u_imageHeight;
       scale.y = 1.0;
   }
   float inv_max_dist = 1.0 / (sqrt(scale.x * scale.x + scale.y * scale.y) * 0.5);
   float range = 1.3 - sqrt(u_floatParam) * 0.7;
   vec2 coord = v_texCoord - vec2(0.5, 0.5);
   float dist = length(coord * scale);

   return shade / (1.0 + exp((dist * inv_max_dist - range) * slope)) + (1.0 - shade);
}

void main() {
    // black white
    vec4 color = texture2D(u_texSampler, v_texCoord);
    vec2 seed = vec2(0.5, 0.5);
    float dither = rand(v_texCoord + seed);
    vec3 xform = clamp(2.0 * color.rgb, 0.0, 1.0);
    float stepsize = 1.0 / 255.0;
    vec3 temp = clamp(2.0 * (color.rgb + stepsize), 0.0, 1.0);
    vec3 new_color = clamp(xform + (temp - xform) * (dither - 0.5), 0.0, 1.0);
    // grayscale
    float gray = dot(new_color, vec3(0.299, 0.587, 0.114));
    new_color = vec3(gray, gray, gray);
    gl_FragColor = vec4(new_color * lumen(), color.a);
}
