precision highp float;

varying vec2 v_texCoord;
uniform sampler2D u_texSampler;
uniform float u_imageWidth;
uniform float u_imageHeight;
uniform float u_floatParam;

#define iChannel0 u_texSampler

void main() {
    vec2 fragCoord = vec2(v_texCoord.x * u_imageWidth, v_texCoord.y * u_imageHeight);
    vec2 iResolution = vec2(u_imageWidth, u_imageHeight);

    // Size of a dot in pixels
    float idealDotSize = 1.0 + (u_imageWidth / 10.0 - 1.0) * u_floatParam;
    // We want to avoid incomplete (cut) dots at the right edge.
    // So we calculate an adjusted dot size.
    float dotCount = floor(u_imageWidth / idealDotSize);
    float dotSize = u_imageWidth / dotCount;

    float radius = dotSize * 0.5;

	// Current quad in pixels
	vec2 quadPos = floor(fragCoord.xy / dotSize) * dotSize;
	// Normalized quad position
	vec2 quad = quadPos/iResolution.xy;
	// Center of the quad
	vec2 quadCenter = (quadPos + dotSize/2.0);
	// Distance to quad center
	float dist = length(quadCenter - fragCoord.xy);

	vec4 texel = texture2D(iChannel0, quad);
	if (dist > radius) {
		gl_FragColor = vec4(0.0);
	}
	else {
		gl_FragColor = texel;
	}
}
