precision highp float;
varying vec2 v_texCoord;
uniform sampler2D u_texSampler;
uniform float u_imageWidth;
uniform float u_imageHeight;
uniform float u_floatParam;

void main() {
    vec2 uv  = v_texCoord.xy;

    // Map floatParam from [0,1] to [1,imageWidth/10]
    float idealPixelSize = 1.0 + (u_imageWidth / 10.0 - 1.0) * u_floatParam;
    // We want to avoid incomplete (cut) pixels at the right edge.
    // So we calculate an adjusted pixel size.
    float pixelCount = floor(u_imageWidth / idealPixelSize);
    float pixelSize = u_imageWidth / pixelCount;

    float pixelWidth = pixelSize / u_imageWidth;
    float pixelHeight = pixelSize / u_imageHeight;
    vec2 coord = vec2(pixelWidth * floor(uv.x / pixelWidth), pixelHeight * floor(uv.y / pixelHeight));
    vec3 tc = texture2D(u_texSampler, coord).xyz;
    gl_FragColor = vec4(tc, 1.0);
}