precision highp float;

varying vec2 v_texCoord;
uniform sampler2D u_texSampler;
uniform float u_imageWidth;
uniform float u_imageHeight;
uniform float u_floatParam;

float Hue_2_RGB(float v1, float v2, float vHue) {
    if (vHue < 0.0) {
        vHue += 1.0;
    }
    if (vHue > 1.0) {
        vHue -= 1.0;
    }
    if ((6.0 * vHue) < 1.0) {
        return (v1 + (v2 - v1) * 6.0 * vHue);
    }
    if ((2.0 * vHue) < 1.0) {
        return v2;
    }
    if ((3.0 * vHue) < 2.0) {
        return (v1 + (v2 - v1) * ((2.0 / 3.0) - vHue) * 6.0);
    }
    return v1;
}

vec3 hslToRgb(vec3 hsl) {
	vec3 rgb;
    float v1, v2;
    float hue = hsl.x / 360.0;

    v2 = (hsl.z < 0.5) ? (hsl.z * (1.0 + hsl.y)) : ((hsl.z + hsl.y) - (hsl.z * hsl.y));
    v1 = 2.0 * hsl.z - v2;

    rgb.r = Hue_2_RGB(v1, v2, hue + (1.0 / 3.0));
    rgb.g = Hue_2_RGB(v1, v2, hue);
    rgb.b = Hue_2_RGB(v1, v2, hue - (1.0 / 3.0));
    return rgb;
}

void main() {
    vec3 tintHsl = vec3(u_floatParam * 360.0, 1.0, 0.5);
    vec3 tint = hslToRgb(tintHsl);
    vec3 color_ratio = vec3(0.21, 0.71, 0.07);

    vec4 color = texture2D(u_texSampler, v_texCoord);
    float avg_color = dot(color_ratio, color.rgb);
    vec3 new_color = min(0.8 * avg_color + 0.2 * tint, 1.0);
    gl_FragColor = vec4(new_color.rgb, color.a);
}
