precision mediump float;

uniform sampler2D tex_sampler_0;
uniform float u_floatParam;
uniform float u_imageWidth;
uniform float u_imageHeight;
varying vec2 v_texCoord;

void main() {
    float shade = 0.85;
    float slope = 20.0;

    float scale1, scale2;
    if (u_imageWidth > u_imageHeight) {
        scale1 = 1.0;
        scale2 = u_imageHeight / u_imageWidth;
    } else {
        scale1 = u_imageWidth / u_imageHeight;
        scale2 = 1.0;
    }

    float inv_max_dist = 1.0 / (sqrt(scale1 * scale1 + scale2 * scale2) * 0.5);
    vec2 scale = vec2(scale1, scale2);
    float range = 1.3 - sqrt(u_floatParam) * 0.7;
    vec2 coord = v_texCoord - vec2(0.5, 0.5);
    float dist = length(coord * scale);
    float lumen = shade / (1.0 + exp((dist * inv_max_dist - range) * slope)) + (1.0 - shade);
    vec4 color = texture2D(tex_sampler_0, v_texCoord);
    gl_FragColor = vec4(color.rgb * lumen, color.a);
}